---
title: "Which branch of readfish should I use?"
alt_titles:
  - "Suitable readfish branch"
---

The `main` branch is the most up to date branch of readfish, and is the one we recommend using.
Watch this space for any updates!
See elsewhere in this file for installation FAQs. 🕵️‍♂️
